@@ -2,20 +2,7 @@
  *
  * Copyright (C) 2002 Matthew Allum
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #define _GNU_SOURCE
@@ -54,9 +41,12 @@ _parse_desktop_entry(MBDotDesktop *dd)
 
   if (fgets(data,256,fp) != NULL)
     {
+      /* FIXME: this check should be moved elsewhere if exist at all */
       if (strncasecmp("[desktop entry]", data, 15))
 	{
-	  fprintf(stderr, "libmb: dont look like a desktop entry? %s\n", data);
+	  if (mb_want_warnings())
+	    fprintf(stderr, "libmb: dont look like a desktop entry? %s\n", 
+		    data);
 	  fclose(fp);
 	  return DD_ERROR_NOT_DESKTOP_FILE;
 	}
@@ -200,7 +190,7 @@ mb_dotdesktop_get_exec (MBDotDesktop *dd)
   /* Source iterator, destination iterator */
   char *s, *d;
   
-  s = source = mb_dotdesktop_get (dd, "Exec");
+  s = source = (char*)mb_dotdesktop_get (dd, "Exec");
   if (source == NULL)
     return NULL;
   
@@ -348,7 +338,7 @@ mb_dot_desktop_icon_get_full_path (char* theme_name,
 		    {
 		      theme_name_cur = NULL;
 		      strncpy(theme_name_cur, 
-			      mb_dotdesktop_get(dd, "Inherits"), 512);
+			      (char*)mb_dotdesktop_get(dd, "Inherits"), 512);
 		      i = 2;
 		    }
 		  mb_dotdesktop_free(dd);
@@ -400,7 +390,8 @@ mb_dot_desktop_folders_new(const char *vfolder_path)
 
   if (!(fp = fopen(order_path, "r"))) 
     { 
-      fprintf(stderr, "libmb: failed to open %s\n", order_path); 
+      if (mb_want_warnings())
+	fprintf(stderr, "libmb: failed to open %s\n", order_path); 
       return NULL;
     }
 
@@ -416,7 +407,8 @@ mb_dot_desktop_folders_new(const char *vfolder_path)
 
   if (!folder_cnt) 
     { 
-       fprintf(stderr, "libmb: no vfolders defined\n"); 
+      if (mb_want_warnings())
+	fprintf(stderr, "libmb: no vfolders defined\n"); 
        fclose(fp); 
        return NULL; 
     }
@@ -450,13 +442,13 @@ mb_dot_desktop_folders_new(const char *vfolder_path)
 		}
 	      memset(entry_cur, 0, sizeof(MBDotDesktopFolderEntry));
 	  
-	      entry_cur->name = strdup(mb_dotdesktop_get(dd, "Name"));
-	      entry_cur->match = strdup(mb_dotdesktop_get(dd, "Match"));
+	      entry_cur->name = (unsigned char*)strdup((char*)mb_dotdesktop_get(dd, "Name"));
+	      entry_cur->match = (unsigned char*)strdup((char*)mb_dotdesktop_get(dd, "Match"));
 
 	      if (mb_dotdesktop_get(dd, "Icon"))
 		{
 		  entry_cur->icon 
-		    = strdup(mb_dotdesktop_get(dd, "Icon"));
+		    = (unsigned char*)strdup((char*)mb_dotdesktop_get(dd, "Icon"));
 		}
 
 	      folders->n_entries++;
