@@ -1,20 +1,7 @@
 /* libmb
  * Copyright (C) 2002 Matthew Allum
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #define _GNU_SOURCE
@@ -348,7 +335,7 @@ _mb_font_load(MBFont *font)
 			    XFT_SIZE, XftTypeDouble   , (double)font->pt_size,
 			    XFT_WEIGHT, XftTypeInteger, weight,
 			    XFT_SLANT, XftTypeInteger , slant,
-			    0);
+			    NULL);
 
   if (font->font != NULL ) result = 2;
 
@@ -791,7 +778,7 @@ mb_font_get_txt_width(MBFont        *font,
    */
 
   attr_list = pango_attr_list_new (); /* no markup - empty attributes */
-  str       = strdup(txt);
+  str       = strdup((char*)txt);
 
   str[byte_len] = '\0';
   /*
@@ -820,8 +807,8 @@ mb_font_get_txt_width(MBFont        *font,
 
        pango_glyph_string_extents (  glyphs,
 				     this->analysis.font,
-				     &rect,
-				     NULL);
+				     NULL,
+				     &rect);
 
        width += (( rect.x + rect.width ) / PANGO_SCALE);
        
@@ -908,11 +895,130 @@ _clip_some_text (MBFont         *font,
 		 int             encoding,
 		 int             opts)
 {
+#ifdef USE_PANGO
+  /* We cache the width of the elipsis for the given font */
+  static int     trailing_width = 0;
+  static MBFont *font_prev = NULL;
+  
+  GList         *items     = NULL, *items_head = NULL;
+  PangoAttrList *attr_list = NULL;
+  int            width     = 0;
+  int            length    = 0;
+  int            done = 0;
+  int            bytelen = strlen((char*)txt);
+
+  /* we can't clip single char string */
+  if (bytelen < 2) return 0;
+
+  if (font != font_prev || !_mb_font_is_font_object_fresh (font))
+    trailing_width = 0; /* different font, recalculate */
+  
+  if (!_mb_font_is_font_object_fresh (font)) /* XXX Make define ? */
+    _mb_font_load(font);
+
+  attr_list = pango_attr_list_new (); /* no markup - empty attributes */
+  
+  /* Measure the trailing elipsis */
+  if ((opts & MB_FONT_RENDER_OPTS_CLIP_TRAIL) && trailing_width == 0)
+    {
+      items = pango_itemize (font->pgo_context, ".", 0, 1, attr_list, NULL);
+
+      if (items)
+	{
+	  PangoItem        *this   = (PangoItem *)items->data;
+	  PangoGlyphString *glyphs = pango_glyph_string_new ();
+	  PangoRectangle    rect;
+       
+	  pango_shape  (".", 1, &this->analysis, glyphs);
+
+	  pango_glyph_string_extents (  glyphs,
+					this->analysis.font,
+					NULL,
+					&rect);
+
+	  trailing_width = ((3 * ( rect.x + rect.width )) / PANGO_SCALE);
+       
+	  pango_item_free (this);
+	  pango_glyph_string_free (glyphs);
+
+	  g_list_free (items);
+
+	  font_prev = font;
+	}
+    }
+
+  /* Measure the actual string */
+  items_head = items = pango_itemize (font->pgo_context, (char*)txt, 0, 
+				      strlen ((char*)txt), attr_list, NULL);
+
+   while (items)
+     {
+       PangoItem *this = (PangoItem *)items->data;
+
+       if (!done)
+	 {
+	   PangoGlyphString *glyphs = pango_glyph_string_new ();
+	   PangoRectangle    rect;
+	   int               rtl = (this->analysis.level & 1);
+	   
+	   pango_shape  ((char*)&txt[this->offset], this->length, 
+			 &this->analysis, glyphs);
+
+	   pango_glyph_string_extents (  glyphs,
+					 this->analysis.font,
+					 NULL,
+					 &rect);
+
+	   width += (( rect.x + rect.width ) / PANGO_SCALE);
+	   length += this->length;
+       
+	   if (width + trailing_width == max_width)
+	     {
+	       done = 1;
+	     }
+	   else if (width + trailing_width > max_width)
+	     {
+	       /* The required break is somewhere in this item */
+	       int k;
+	       int trim = width + trailing_width - max_width;
+	       int byte_off = 0;
+	       
+	       for (k = 0; k < glyphs->num_glyphs; ++k)
+		 {
+		   int indx = rtl ? k : glyphs->num_glyphs - k - 1;
+		   
+		   trim -= (glyphs->glyphs[indx].geometry.x_offset +
+			    glyphs->glyphs[indx].geometry.width) / PANGO_SCALE;
+
+		   byte_off = glyphs->log_clusters[indx];
+		   
+		   if (trim <= 0)
+		     break;
+		 }
+
+	       length -= (this->length - byte_off);
+	       done = 1;
+	     }
+	   
+	   pango_glyph_string_free (glyphs);
+	 }
+       
+       pango_item_free (this);
+       items = items->next;
+     }
+
+   
+   pango_attr_list_unref (attr_list);
+   
+   if (items_head) g_list_free (items_head);
+
+   return length;
+   
+#else
   int len = strlen((char*)txt);
 
   /* we cant clip single char string */
   if (len < 2) return 0;
-
   /* XXX RTL case for pango */
 
   if (opts & MB_FONT_RENDER_OPTS_CLIP_TRAIL)
@@ -958,6 +1064,7 @@ _clip_some_text (MBFont         *font,
       else len--;
     }
   return len;
+#endif
 }
 
 void
@@ -988,10 +1095,10 @@ _render_some_text (MBFont        *font,
    */
 
    attr_list = pango_attr_list_new (); /* no markup - empty attributes */
-   str       = strdup(text);
+   str       = (unsigned char*)strdup((char*)text);
 
    /* analyse string, breaking up into items */
-   items_head = items = pango_itemize (font->pgo_context, str, 
+   items_head = items = pango_itemize (font->pgo_context, (char*)str, 
 				       0, bytes_to_render,
 				       attr_list, NULL);
 
@@ -1002,7 +1109,7 @@ _render_some_text (MBFont        *font,
        PangoRectangle    rect;
        
        /* shape current item into run of glyphs */
-       pango_shape  (&str[this->offset], this->length, 
+       pango_shape  ((char*)&str[this->offset], this->length, 
 		     &this->analysis, glyphs);
 
        /* render the glyphs */
@@ -1015,8 +1122,8 @@ _render_some_text (MBFont        *font,
        /* calculate rendered area */
        pango_glyph_string_extents (glyphs,
 				   this->analysis.font,
-				   &rect,
-				   NULL);
+				   NULL,
+				   &rect);
 
        x += ( rect.x + rect.width ) / PANGO_SCALE; /* XXX Correct ? */
        
@@ -1063,7 +1170,7 @@ mb_font_render_simple (MBFont          *font,
 		       int              encoding,
 		       MBFontRenderOpts opts )
 {
-  int render_w = 0, len = 0, orig_len = 0;
+  int render_w = 0, len = 0;
   unsigned char *str = NULL;
   Bool want_dots = False;
 
@@ -1080,7 +1187,7 @@ mb_font_render_simple (MBFont          *font,
   if (!_mb_font_is_font_object_fresh (font))
     _mb_font_load(font);
 
-  orig_len = len = strlen((char*)text);
+  len = strlen((char*)text);
 
   str = malloc(len+3);
   memset(str, 0, len+3);
@@ -1157,7 +1264,7 @@ mb_font_render_simple_get_width (MBFont          *font,
 				 int              encoding,
 				 MBFontRenderOpts opts )
 {
-  int render_w = 0, len = 0, orig_len = 0;
+  int render_w = 0, len = 0;
   unsigned char *str = NULL;
   Bool want_dots = False;
 
@@ -1166,7 +1273,7 @@ mb_font_render_simple_get_width (MBFont          *font,
   if (!_mb_font_is_font_object_fresh (font))
     _mb_font_load(font);
 
-  orig_len = len = strlen((char*)text);
+  len = strlen((char*)text);
 
   str = malloc(len+3);
   memset(str, 0, len+3);
@@ -1249,7 +1356,7 @@ mb_layout_get_geometry (MBLayout *layout, int *width, int *height)
 	 }
        else
 	 { 
-	   nbytes++; *txt++; 
+	   nbytes++; txt++;
 	 }
       
      line_width = mb_font_get_txt_width(layout->font, start, 
@@ -1552,8 +1659,8 @@ mb_util_utf8_len()
 int 				/* XXX this can be much smaller see glib */
 mb_util_next_utf8_char(unsigned char **string)
 {
-  unsigned char *s, mask;
-  int length;
+  unsigned char *s;
+  int length, tmp;
   
   s = *string;
 
@@ -1566,33 +1673,34 @@ mb_util_next_utf8_char(unsigned char **string)
   }
   
   if((*s & 0xe0) == 0xc0) { /* 110xxxxx followed by one trailer */
-    mask = 0x1f; length = 1;
+    length = 1;
   } else if ((*s & 0xf0) == 0xe0) { 
     /* 1110xxxx followed by two trailers */     
-    mask = 0x0f; length = 2;
+    length = 2;
   } else if ((*s & 0xf8) == 0xf0) { 
     /* 11110xxx followed by three trailers */     
-    mask = 0x07; length = 3;
+    length = 3;
   } else if((*s & 0xfc) == 0xf8) { 
     /* 111110xx followed by four trailers */     
-    mask = 0x03; length = 4;
+    length = 4;
   } else if((*s * 0xfe) == 0xfc) { 
     /* 1111110x followed by five trailers */     
-    mask = 0x01; length = 5;
+    length = 5;
   } else { /* 1111111x is invalid in UTF8 */     
     return -1;
   }
 	    
-  *s++;
-  while(length-- > 0) {
+  s++;
+  tmp = length;
+  while(tmp-- > 0) {
     if((*s & 0xc0) != 0x80) { /* trailer must be 10xxxxxx */
       /* ERROR */ 
       return -1;
     }
-    *s++;
+    s++;
   } 
   
   *string = s; 
-  return length;
+  return length + 1;
 
 }
