@@ -1,20 +1,7 @@
 /* libmb
  * Copyright (C) 2002 Matthew Allum
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #define _GNU_SOURCE
@@ -23,6 +10,8 @@
 #include "config.h"
 #endif
 
+#include <X11/XKBlib.h>
+
 #include "mbmenu.h"
 
 #define MBMAX(x,y) ((x>y)?(x):(y))
@@ -69,7 +58,6 @@ static void remove_xmenus(MBMenu *mb,MBMenuMenu *active[]);
 
 static void menu_set_theme_from_root_prop(MBMenu *mb);
 
-#ifdef USE_XSETTINGS
 /*
  Gtk/FontName
 */
@@ -129,8 +117,6 @@ mbmenu_xsettings_notify_cb (const char       *name,
     }
 }
 
-#endif
-
 MBMenu *
 mb_menu_new(Display *dpy, int screen) 
 {
@@ -193,16 +179,12 @@ mb_menu_new(Display *dpy, int screen)
 
   menu_set_theme_from_root_prop(mbmenu);
 
-#ifdef USE_XSETTINGS
-
   /* This will trigger callbacks instantly so called last */
 
   mbmenu->xsettings_client = xsettings_client_new(mbmenu->dpy, mbmenu->screen,
 						  mbmenu_xsettings_notify_cb,
 						  NULL,
 						  (void *)mbmenu );
-#endif
-
   return mbmenu;
 }
 
@@ -228,8 +210,9 @@ mb_menu_set_default_icons(MBMenu *mbmenu, char *folder, char *app)
       if ((mbmenu->img_default_app
 	   = mb_pixbuf_img_new_from_file(mbmenu->pb, app)) == NULL)
 	    {
-	      fprintf(stderr, "libmb: failed to get load image: %s\n", 
-		      app);
+	      if (mb_want_warnings())
+		fprintf(stderr, "libmb: failed to get load image: %s\n", 
+			app);
 	      mbmenu->img_default_app = NULL;
 	    }
       else
@@ -257,8 +240,9 @@ mb_menu_set_default_icons(MBMenu *mbmenu, char *folder, char *app)
 	   = mb_pixbuf_img_new_from_file(mbmenu->pb, 
 					 folder)) == NULL)
 	{
-	  fprintf(stderr, "libmb: failed to get load image: %s\n", 
-		  folder);
+	  if (mb_want_warnings())
+	    fprintf(stderr, "libmb: failed to get load image: %s\n", 
+		    folder);
 	  mbmenu->img_default_folder = NULL;
 	}
       else
@@ -701,7 +685,8 @@ menu_set_theme_from_root_prop(MBMenu *mb)
   if (status != Success || value == 0
       || *value == 0 || n == 0)
     {
-      fprintf(stderr, "mbmenu: no _MB_THEME set on root window\n");
+      if (mb_want_warnings())
+	fprintf(stderr, "mbmenu: no _MB_THEME set on root window\n");
     } else {
       strcpy(app_cfg, value);
       strcat(app_cfg, "/theme.desktop");
@@ -781,10 +766,8 @@ mb_menu_handle_xevent(MBMenu *mb, XEvent *an_event)
       return;
     }
 
-#ifdef USE_XSETTINGS
   if (mb->xsettings_client != NULL)
     xsettings_client_process_event(mb->xsettings_client, an_event);
-#endif
 
   if (an_event->type == PropertyNotify 
       && an_event->xproperty.atom == mb->atom_mbtheme) 
@@ -799,7 +782,7 @@ mb_menu_handle_xevent(MBMenu *mb, XEvent *an_event)
     {
     case KeyPress:
       MENUDBG("%s() Keyevent recieved\n", __func__ );
-      switch (key = XKeycodeToKeysym (mb->dpy, an_event->xkey.keycode, 0))
+      switch (key = XkbKeycodeToKeysym (mb->dpy, an_event->xkey.keycode, 0, 0))
 	{
 	case XK_Left:
 	  if (mb->active_depth > 0)
@@ -1060,7 +1043,7 @@ static MBMenuMenu *
 new_menu(MBMenu *mb, char *title, int depth)
 {
   MBMenuMenu *menu = (MBMenuMenu *)malloc(sizeof(MBMenuMenu));
-   memset(menu, 0, sizeof(menu));
+   memset(menu, 0, sizeof(*menu));
    menu->items = NULL;
 
    MENUDBG("adding menu -> %s, (%i) \n", title, depth);
@@ -1104,10 +1087,12 @@ new_menu_item(MBMenu *mb, char *title, char *icon, char *info,
    menu_item->icon_fn   = NULL;
    menu_item->img       = NULL;
 
-   if (title == NULL) {
-      fprintf(stderr, "Cant create menu with no title\n"); 
-      exit(0);
-   }
+   if (title == NULL) 
+     {
+       if (mb_want_warnings())
+	 fprintf(stderr, "Cant create menu with no title\n"); 
+       exit(0);
+     }
 
    MENUDBG("adding menu item -> %s\n", title);
    
@@ -1146,7 +1131,8 @@ new_menu_item(MBMenu *mb, char *title, char *icon, char *info,
 	}
       else
 	{
-	  fprintf(stderr, "failed to load image: %s \n", menu_item->icon_fn);
+	  if (mb_want_warnings())
+	    fprintf(stderr, "failed to load image: %s \n", menu_item->icon_fn);
 	  free(menu_item->icon_fn);
 	  menu_item->icon_fn = (char *)NULL;
 	}
