@@ -2,28 +2,18 @@
  *
  * Copyright (C) 2002 Matthew Allum
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #define _GNU_SOURCE
 
 #include <strings.h>
+
 #include "mbpixbuf.h"
 #include "mbutil.h"
 
+#include <setjmp.h>
+
 #define BYTE_ORD_24_RGB  0
 #define BYTE_ORD_24_RBG  1
 #define BYTE_ORD_24_BRG  2
@@ -1029,6 +1019,54 @@ mb_pixbuf_img_new_from_int_data(MBPixbuf            *pixbuf,
   return img;
 }
 
+MBPixbufImage *
+mb_pixbuf_img_new_from_long_data(MBPixbuf            *pixbuf,
+				const unsigned long  *data,
+				int                  width,
+				int                  height)
+{
+  MBPixbufImage *img;
+  int            i=0,x,y;
+
+  img = mb_pixbuf_img_rgba_new(pixbuf, width, height);
+
+  if (pixbuf->internal_bytespp == 3)
+    {
+      unsigned char *p = img->rgba;
+
+      for (y=0; y<height; y++)
+	for (x=0; x<width; x++)
+	  {
+	    *p++ = (data[i] >> 16) & 0xff;
+	    *p++ = (data[i] >> 8) & 0xff;
+	    *p++ = data[i] & 0xff;
+	    *p++ = data[i] >> 24;
+	    i++;
+	  }
+    }
+  else
+    {
+      unsigned char *p = img->rgba, r,g,b,a;
+
+      for (y=0; y<height; y++)
+	for (x=0; x<width; x++)
+	  {
+	    r = ((data[i] >> 16) & 0xff);
+	    g = ((data[i] >> 8) & 0xff);
+	    b = (data[i] & 0xff);
+	    a = (data[i] >> 24);
+
+	    internal_rgb_to_16bpp_pixel(r,g,b,p);
+	    internal_16bpp_pixel_next(p);
+	    *p++ = a;
+
+	    i++;
+	  }
+    }
+
+  return img;
+}
+
 MBPixbufImage *
 mb_pixbuf_img_new_from_data(MBPixbuf            *pixbuf, 
 			    const unsigned char *data,
@@ -1406,8 +1444,7 @@ mb_pixbuf_img_fill(MBPixbuf *pb,
 	  {
 	    internal_rgb_to_16bpp_pixel(r,g,b,p);
 	    internal_16bpp_pixel_next(p);
-	    if (img->has_alpha) 
-	      { *p = a; *p++; }
+	    if (img->has_alpha) *p++ = a;
 	  }
     }
   else
