@@ -1,20 +1,7 @@
 /* libmb
  * Copyright (C) 2002 Matthew Allum
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef _MB_TRAY_H_
@@ -29,7 +16,7 @@
 #include <X11/Xatom.h>
 #include <X11/Xmd.h>
 
-#include "libmb/mb.h"
+#include <libmb/mb.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -279,7 +266,7 @@ mb_tray_app_set_theme_change_callback (MBTrayApp              *mb_tray_app,
  *
  * @param mb_tray_app Tray instance
  * @param poll_cb timeout callback
- * @param tv      a timeval struct specifying the timeout
+ * @param tv      a timeval struct specifying the timeout.
  */
 void
 mb_tray_app_set_timeout_callback (MBTrayApp              *mb_tray_app, 
@@ -348,8 +335,14 @@ void
 mb_tray_app_request_offset (MBTrayApp *mb_tray_app, 
 			    int        offset);
 
-
-void  				/* XXX needed ? */
+/**
+ * Set timing for any timeout callbacks.
+ *
+ * @param mb_tray_app Tray instance
+ * @param  tv      a timeval struct specifying the timeout. Pass NUll to clear
+ *                 any timeout callbacks.
+ */
+void
 mb_tray_app_set_poll_timeout (MBTrayApp      *mb_tray_app, 
 			      struct timeval *tv );
 
