@@ -1,20 +1,7 @@
 /* libmb
  * Copyright (C) 2002 Matthew Allum
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #define _GNU_SOURCE   /* X11.pc sets -DXOPEN flag which this works round */
@@ -376,7 +363,6 @@ mb_want_warnings ()
 
   if (env_checked == 0)
     env_checked = getenv("MB_WARNINGS") ? 1 : 2;
-  else
-    return env_checked-1;
+  return env_checked-1;
 }
 
